/*
;---TruRand--- 
;z80 ASM Random Number Generation System
;for the TI-83 Graphing Calculator
;Version: 1.0
;By Adam Brooke
;As Part of BASM
;http://come.to/tiasm
;e-mail at:
;webmaster@blankware.zzn.com
;----------------------------
;WHAT IS TRURAND???

;If you program in ASM for the TI-83, you probably know that the random
;number routines in libraries such as zlib don't make true random 
;numbers - in fact, not even close.  I've attempted to solve that 
;problem by making truRand, which generates more truly random
;numbers than any other code I've found.
;
;-------------------
;HOW TO USE...
;
;First copy the entire source of trurand.z80 into your ASM code.  
;TruRand can generate random numbers between 0 and 9999.  To 
;generate an integer between, say, 0 and 50, load hl with 50 and
;then call truRand.  The random number will be returned in hl.
;For example:
;
;ld hl,50
;call truRand
;
;That's it!  When the truRand function returns to this code, hl will 
;contain the random number between 0 and 50.  It's up to you to decide
;what to do with it next :)  Anyways, remember that what you're loading
;into hl before calling truRand is the scaling factor, you'll
;have to do the shifting value seperate... if you wanted a random number
;between 50 and 125, you'd first have to generate a random number 
;between 0 and 50, and then add 75 to that value.
;-------------------
;COMMENTS
;
;Well, that's about it.  I wasn't sure why nobody had made something like
;this already, so I went ahead and did it myself... if you use truRand 
;in your program(s), all I ask is that you give me a little bit of credit
;in the documentation.  Also, the source code (all 11 lines
;of it) is fully commented so you can learn something from it.  I 
;WOULD NOT recommend changing it in any way, though, as EVERYTHING is 
;there for a reason!  There's a few things that you might be able to
;modify to fit your needs, such as rounding to decimal places instead 
;of an integer, (to create random money amounts) etc.
;
;-------------------
;THANKS TO
;
;Joe Wingbermuele - For helping me out on his message board.
;TI's documentation - For explaining a lot about the opx functions.
;
;-------------------
;FUTURE VERSIONS
;
;Unless there's something that could drastically reduce the size of
;this routine or increase it's efficiency, probably not...
;
;-------------------
;USE IN LIBRARIES???
;
;If you want to use this routine in a library you're making, go right
;ahead, but make sure that you contact me at webmaster@blankware.zzn.com
;about it and give me full credit in the library source and 
;documentation.
;-------------------
;      Thanks,
;	-Adam Brooke
;	   -http://come.to/tiasm
;	      -webmaster@blankware.zzn.com
*/
#ifndef _RAND16_C
#define _RAND16_C

/* Wehhh.. this routine returns (sometimes?) an
   "ERR: INVALID DIM". I know a bit what is causing that,
   but not how to cure it.
    PLEASE HELP
 */

randint() {
#asm
	ld	hl,$FFFF	; WE ALWAYS WANT AN INT...
	push	hl		;secure hl for later
	call	_RANDOM		;random decimal between 0 and
                                ;  .99999999, returned to op1
	pop	hl		;get back hl
	call	_SETXXXXOP2	;set op2 = HL == upper bound
	call	_FPMULT		;multiply op1 by op2
	ld	d,0		;the decimal places to round to (zero)
	call	_ROUND		;round op1 to d decimal places
	call	_CONVOP1	;set de = op1
	ex	de,hl		;exchange the values for de and hl
	ret			;return to calling function
#endasm
 }
#endif