#ifndef _REMOVE_C
#define _REMOVE_C

/* Remove a program on the TI-83

   Small-C library, by Henk Poley (hpoley@dds.nl)
   (---no www addres---)

   Synopsis:
      remove(*str)

   Description:
      o Removes program in string 'str'
	- returns 0 if everything went correct (program is deleted)
        - returns 1 if an error occured:
         o Unknown program:
            The program simply doesn't exist, so it can't be deleted...
         o String to big:
            The max. size a programs name is 8 bytes. So if the string
            is >8 bytes (not counting \0), no such program can be
            found.

   Example:
      remove("BLA");

       -or-

      {
      char foo;
      foo[]="BLA";
      remove(&foo); ***is this right ?***
      }

   Output:
      Program 'PrgmBLA' is deleted.

   Notes:
      o I didn't test it, like most of my routines...

      o Shouldn't the Object-type be 5Fh instead of 05h?
*/

remove(str) char *str;
{
#asm
; Most of this routine is ripped from DELPROG:
;
; PROGRAM:    DELPROG
; VERSION:    1.01
; AUTHOR:     David Eriksson
; DATE:       10/05/96
;
; hl = pointer to program to delete
;
	call	_ZEROOOP1		; Clear OP1
					;
	ld	hl,2			; The string-pointer is
	add	hl,sp			;  at SP+2.
	call	LD_HL_MHL		; HL = pointer at (HL)
					;
	ld	de,OP1			; A = adress of OP1
	ld	a,05h			; The object type is 'program'
	ld	(de),a			; Store it in first byte of OP1
	ld	b,9			; Maximum B-1 bytes to copy
					;
remove_loop:
	inc	de			; next byte of OP1
	ld	a,(hl)			; get a byte of the string
	or	a			; if(A = 0), done copying
	jr	z,next_remove		;  goto next label
	ld	(de),a			; Store the byte in OP1+xx
	inc	hl			; Next byte of string
	dec	b			; Maximum B-1 times again
	jr	z,error_remove		; if(B = 0), ERROR!
	jr	remove_loop		; go back for next character
					;
next_remove:
	call	_CHKFINDSYM		; Search the VAT for the entry
					;  stored in OP1
	jr	c,error_remove		; if(error), jump...
	call	_DELVAR			; Delete program!
	ld	hl,0			; Return(0), no errors
	ret
error_remove:
	ld	hl,1			; Return(1), an error occured!
					;  reasons:
					;   - An unknown program
					;   - String to big
#endasm
}
#endif	/* _REMOVE_C LOADED */