/* CTYPE.C: Character expressions */

/* Several Ideas for code from "Dr. Dobbs Z80 Toolbook" */

/* This function sets up a "is*"-function for initalization! Expands to:
 * ld	hl,2
 * add	hl,sp
 * ld	a,(hl)
 * xor	a
 * ld	h,a
 * ld	l,a
 */
#define SetupIs              asm("\tld\thl,2\n\tadd\thl,sp\n\tld\ta,(hl)\n\txor\ta\n\tld\th,a\n\tld\tl,a\n");

/*
 * CheckGroup(expr, min, max) macro expands to
 * _expr:
 * cp	'min'
 * ret	c
 * cp	'max'+1
 * ret	nc
 * inc	l
 */
#define CheckGroup(expr, min, max) asm("_" #expr ":\n\tcp\t'" #min "'\n\tret\tc\n\tcp\t'" #max "'+1\n\tret\tnc\n\tinc\tl\n");

/* Check for characters (A-Z, a-z, 0-9) */
isalnum(c) char c;
{
	SetupIs;
#asm
	call _islower
	call _isupper
	call _isdigit
#endasm
}

/* Check for characters (A-Z, a-z) */
isalpha(c) char c;{
	SetupIs;
#asm
	call _islower
	call _isupper
#endasm
}

/* COMMENTED OUT
   returns 'not zero' in HL, if 'char c' is a Control Character.
   Control Characters are 0 - 31 and 127 (ASCII Character Set)
iscntrl(c) char c;
 {
 ...
 ...
 ...
 }
   COMMENTED OUT */

/* returns 'not zero' in HL, if 'char c' is a number (0 - 9)
   Numbers are 48 - 57 (ASCII Character Set) */
isdigit(c) char c;{
	SetupIs;
	CheckGroup(isdigit, 0,9);
}

/* COMMENTED OUT
   returns 'not zero' in HL, if 'char c' is a 'printable character' (but not a space).
   'Printable characters' are .. - .. (ASCII Character Set) ???
isgraph(c) char c;
 {
 ...
 ...
 ...
 }
   COMMENTED OUT */

/* returns 'not zero' in HL, if 'char c' is a lowercase characters
   lowercase characters are 97 - 122 (ASCII Character Set) ??? */
islower(c) char c;{
	SetupIs;
	CheckGroup(islower, a,z);
}

/* COMMENTED OUT
   returns 'not zero' in HL, if 'char c' is a 'printable character' (including a space).
   'Printable characters' are .. - .. (ASCII Character Set) ???
isprint(c) char c;
 {
 ...
 ...
 ...
 }
   COMMENTED OUT */

/* COMMENTED OUT
   returns 'not zero' in HL, if 'char c' is an interpuction character.
   interpuction characters are  '.', '?', '!', etc.
                                 46,  63,  33, etc. (ASCII Character Set)
ispunct(c) char c;
 {
 ...
 ...
 ...
 }
   COMMENTED OUT */

/* returns 'not zero' in HL, if 'char c' is a 'white space'.
   white spaces are:
    space             (32)
    formfeed       (\f,12)
    cariage-return (\n,13)
    tab            (\t, 9)
    vertical tab   (\v,11)
   Not all of these are implemented because some of them
    are a bit useless */
isspace(c) char c;{
#asm
	ld	hl,2
	add	hl,sp
	ld	a,(hl)
        ld      hl,1            ; Default to true

	cp	9		; Tab check
	ret	z

	cp	10		; Newline check
	ret	z

        cp      ' '             ; Space check (ASCII: 32)
	ret	z
    
	dec hl
#endasm
}

/* returns 'not zero' in HL, if 'char c' is a uppercase character
   uppercase characters are 65 - 90 (ASCII Character Set) ??? */
isupper(c) char c;{
	SetupIs;
	CheckGroup(isupper, A,Z);
}

/* COMMENTED OUT
   returns 'not zero' in HL, if 'char c' is a HEX number
   interpuction characters are  0 - 9, A - F, a - f
                                48-57, 65-70, 97-102 (ASCII Character Set)
isxdigit(c) char c;
 {
 ...
 ...
 ...
 }
   COMMENTED OUT */

/* Returns uppercase value of 'char c' if 'char c' is a lowercase
    character, else it will return the input(ed) value. */
toupper(c) char c;{
#asm
	ld	hl, 2
	add	hl, sp
	ld	a, (hl)
	ld	h, 0
	ld	l, a

	cp	'a'
	ret	c
	cp	'z'+1
	ret	nc

	sub	32

	ld	l,a
#endasm
}

/* Returns lowercase value of 'char c' if 'char c' is a uppercase
    character, else it will return the input(ed) value. */
tolower(c) char c;{
#asm
	ld	hl,2
	add	hl,sp
	ld	a,(hl)
	ld	h,0
	ld	l,a

	cp	'A'
	ret	c
	cp	'Z'+1
	ret	nc

	add A, 32

	ld  l,a
#endasm
}
