#ifndef SPRITE_T_C
#define SPRITE_T_C

/* Small c library, by Chris Dannemiller (dannemiller@hotmail.com)

   Ported from the TI-85 code by:

   Jeremy Dewey (jxd45@po.cwru.edu)
   http://www.seashellinc.com/jdewey

   Synopsis:
      sprite_tran(char* spr, char x, char y, char width, char height)

   Description:
      Draws a sprite at position (x,y) of size width x height, with a
      maximum width of 8.  Draws only 1's skips 0's so this is the
      transparent method of drawing

   Example:
      extern char my_sprite[6];   [6 lines sprite]
      sprite_tran(my_sprite, 10, 10, 7, 6);

   Notes:
      o Sprites must be stored from top down, each line beginning on
        byte boundaries. If the sprite is < 8 pixels wide, it must use
        the most significant bits to store its data.

      o See also sprite.c (sprite drawn to the screen) and sprite_x.c
        (black pixels are XOR'ed to screen)

*/

#ifndef SPRT_VAR
#define SPRT_VAR
#ifndef __PIXEL_C_
#include <pixel.c>
#endif
char* _spr;
char _spr_h;
#endif
sprite_tran(spr, x, y, w, h) char *spr, x, y, w, h; {
#asm
   ld   hl,10
   add  hl,sp
   call _gint
   ld   (_spr),hl    ; put sprite pointer into _spr
   ld   hl,6
   add  hl,sp
   ld   d,(hl)       ; put y into c
   ld   hl,2
   add  hl,sp
   ld   a,(hl)
   ld   (_spr_h),a   ; put height into _spr_h

_sprt_ln:
   ld   hl,8
   add  hl,sp
   ld   e,(hl)       ; put x into b
   ld   hl,4
   add  hl,sp
   ld   b,(hl)       ; put width into d
   ld   hl,(_spr)
   ld   a,(hl)
   ld   c,a          ; load line into e
_sprt_pi:
   push bc
   push de
   ld   a,c
   and  $80
   call nz,_putpix
   pop  de
   pop  bc
   sla  c
   inc  e
   dec  b
   jr   nz,_sprt_pi
   ; any more lines?
   ld   hl,_spr_h
   dec  (hl)
   jr   z,_sprt_end
   ; prepare next line
   inc  d
   ld   hl,_spr
   inc  (hl)
   jr   _sprt_ln
_sprt_end:
#endasm
}

#endif /* SPRITE_T_C */
