/* TI-83 Definitions File */

#ifndef __TILOADED__
#define __TILOADED__

/* So TASM knows what calc it is */
#asm
#define __TI83__
#endasm

/* some default defines
   Taken from another Small-C compiler, so maybe
   a bit out off the order here.*/
/* #define ERR   (-2)  .. return value for errors */
/* #define EOF   (-1)  .. return value for end-of-file */
#define FILE  char  /* supports "FILE *fp[x];" declarations */
#define YES      1  /* true */
#define NO       0  /* false */
#define TRUE     1
#define FALSE    0
#define NULL     0  /* zero */
#define CR      13  /* ASCII carriage return */
#define LF      10  /* ASCII line feed */
#define BELL     7  /* ASCII bell */
#define SPACE  ' '  /* ASCII space */
#define NEWLINE LF  /* Small C newline character */


/* Macros

Macro Name	Description
----------------------------------------------------------------------------
clrscrn		Clears The Text form the Screen
clrlcd		Clears the hole LCD screen
indicatoroff	This turns the annoying run indicator off
indicatoron	This turns the annoying run indicator on
displaygraph	This function displays whatever graphing equations are stored
		in the calculator.
nl		This function makes a new line on the screen like a \n in
		Most C programing

screencopy	This command copies the ti backbuffer to the screen
clearbuffer	This command clears the ti backbuffer
*/

#define clrscrn		asm("\tcall\t_clrScrnFULL\n")
#define clrlcd		asm("\tcall\t_CLRLCDFULL\n")

#define indicatoroff	asm("\tcall\t_runIndicOff\n")
#define indicatoron	asm("\tcall\t_runIndicOn\n")

#define displaygraph	asm("\tcall\t_PDspGrph\n");

#define nl		asm("\tcall\t_newline\n");

#define screencopy	asm("\tcall\t_GRBUFCPY_V\n");

#define clearbuffer	asm("\tcall\t_GRBUFCLR\n");

/* Pixel Definitions

These are used when calling functions like line, pixel, and Box

PT_OFF		Turns the pixel/pixels off
PT_ON		Turns the pixel/pixels on
PT_CHG		Inverts the pixel/pixels

*/

#define PT_OFF		0x00
#define PT_ON		0x01
#define PT_CHG		0x02

/* Basic TI Commands

	Function	Description
--------------------------------------------------------------------------
	setxy(x,y)	This function moves the text cursor to the specified
			(x,y) location

	putm(c)		Puts a character on the current location

	putc(c)		Puts the character on the current location and move the
			cursor over one space

	puts(str)	This command puts a specified string at the current
			cursor location and moves the cursor location up


	getkey()	This command waits for a key or the APD register
			to clear. The calculator will be in low power stand-
                        by during this process. It returns a value refered
                        to the kXXXX table (at the end of this document).
*/

setxy(x,y) char x, y; {
#asm
	ld	hl,2
	add	hl,sp
	ld	a,(hl)
	ld	(CURROW),a
	inc	hl
	inc	hl
	ld	a,(hl)
	ld	(CURCOL),a
#endasm
}

putm(c) char c; {
#asm
	ld	hl,2
	add	hl,sp
	ld	a,(hl)
	jp	_putmap
;no ret
#endasm
}

putc(c) char c; {
#asm
	ld	hl,2
	add	hl,sp
	ld	a,(hl)
	jp	_putc
;no ret
#endasm
}

puts(str)
char* str;
{
#asm
	ld	hl,2
	add	hl,sp
	call	LD_HL_MHL	; size optimize :)
; At this point HL is pointer to what we want
;	To add support for \n we will not be using the _puts routine
;
puts_top:
	ld	a,(hl)
	and	a
;	jr	z,puts_end	; You can better do a "RET Z"
				; So you don't have to jump to
				; a RET yourself...
				; Which means there there doesn't
				; need to be a "puts_end" label
	ret	z
	cp	10
        call    z,_newline
	cp	10
        call    nz,_putc
	inc	hl
	jr	puts_top
				; No "puts_nl:" here anymore...
				;
				; TIP: use the next one of no RET is needed
				;      at the end of this routine. The RET
				;      will be removed in optimization.
;no ret
#endasm
}

getkey()
{
#asm
	call	_getkey
	ld	l,a
	ld	h,0
#endasm
}

/* These are the values that would be returned by getkey() */
/* Need to be sorted! */

#define kRight		0x01
#define kLeft		0x02
#define kUp		0x03
#define kDown		0x04
#define kEnter		0x05
#define kALPHAENTER	0x06
#define kALPHAUP	0x07
#define kALPHADOWN	0x08
#define kClear		0x09
#define kDEL		0x0A
#define kINS		0x0B
#define kRecall		0x0C
#define kLastEnt	0x0D
#define kBOL		0x0E
#define kEOL		0x0F
#define kPrgm		0x20
#define kZOOM		0x2E
#define kDRAW		0x2F
#define kSPLOT		0x30
#define kSTAT		0x31
#define kMATH		0x32
#define kTEST		0x33
#define kVARS		0x35
#define kMem		0x36
#define kMATRIX		0x37
#define kDIST		0x38
#define kANGLE		0x39
#define kLIST		0x3A
#define kCALC		0x3B
#define kFIN		0x3C
#define CATALOG		0x3E
#define kQuit		0x40
#define kExit		0x40	/* For support against the 86 */
#define kLinkIO		0x41
#define kGRAPH		0x44
#define kMODE		0x45
#define kWINDOW		0x48
#define kYEQU		0x49
#define kTABLE		0x4A
#define kTBLSET		0x4B
#define kFORMAT		0x57
#define kTRACE		0x5A
#define kAdd		0x80
#define kSub		0x81
#define kMul		0x82
#define kDiv		0x83
#define kExpon		0x84 /* is '^' */
#define kLParen		0x85
#define kRParen		0x86
#define kLBRACK		0x87
#define kRBRACK		0x88
#define kStore		0x8A
#define kCOMMA		0x8B
#define kChs		0x8C /* 'little -' ?*/
#define kDecPnt		0x8D /* period ? */
#define k0		0x8E
#define k1		0x8F
#define k2		0x90
#define k3		0x91
#define k4		0x92
#define k5		0x93
#define k6		0x94
#define k7		0x95
#define k8		0x96
#define k9		0x97
#define kEE		0x98
#define kSPACE		0x99
#define kCapA		0x9A
#define kCapB		0x9B
#define kCapC		0x9C
#define kCapD		0x9D
#define kCapE		0x9E
#define kCapF		0x9F
#define kCapG		0xA0
#define kCapH		0xA1
#define kCapI		0xA2
#define kCapJ		0xA3
#define kCapK		0xA4
#define kCapL		0xA5
#define kCapM		0xA6
#define kCapN		0xA7
#define kCapO		0xA8
#define kCapP		0xA9
#define kCapQ		0xAA
#define kCapR		0xAB
#define kCapS		0xAC
#define kCapT		0xAD
#define kCapU		0xAE
#define kCapV		0xAF
#define kCapW		0xB0
#define kCapX		0xB1
#define kCapY		0xB2
#define kCapZ		0xB3
#define kVarx		0xB4
#define kPi		0xB5
#define kINV		0xB6 /* X^-1 */
#define kSin		0xB7
#define kASin		0xB8
#define kCos		0xB9
#define kACos		0xBA
#define kTan		0xBB
#define kATan		0xBC
#define kSQUARE		0xBD /* ^2 */
#define kSQRT		0xBE /* V~(..) */
#define kLN		0xBF
#define kEXP		0xC0 /* e^X */
#define kLOG		0xC1
#define kALOG		0xC2
#define kAns		0xC5
#define kcolon		0xC6
#define kQUEST		0xCA
#define kQUOTE		0xCB
#define kTHETA		0xCC
#define kLBRACE		0xEC
#define kRBracE		0xED /* kRBRACE ? */
#define ki		0xEE
#define KCONSTeA	0xEF
#define kL1A		0xF3
#define kL2A		0xF4
#define kL3A		0xF5
#define kL4A		0xF6
#define kL5A		0xF7
#define kL6A		0xF8
#define kUNA		0xF9
#define kVNA		0xFA
#define kWNA		0xFB

#endif /* __TILOADED__ */
