/* TI-85 Usgard Definitions File 

   I ripped most (all) of it from 'Smallc4.1 for the TI85 running
   Usgard'. That is why there are some things 'switched off'.
   Anyone who knows more about Usgard and has a TI85 of his own (and
   can program in Assembly), is hereby invited to make make these
   things work. 

   Other programmers for other assembly shells on the TI85
   (or TI-eighteens) are also invited to make this Small-C compiler
   something to work with, for all TI-eigteens calculators.

   I think everybody knows about the famous C-compiler for the
   TI92(+)/TI89. We should work together to make this compiler
   as good as that one.

	greetz,
	Henk Poley
*/

#ifndef __TILOADED__
#define __TILOADED__

/* So TASM knows what calc it is */
#asm
#define __TI85__
#define __USGARD__
#endasm

/* some default defines
   Taken from another Small-C compiler, so maybe
   a bit out off the order here.*/
/* #define ERR   (-2)  .. return value for errors */
/* #define EOF   (-1)  .. return value for end-of-file */
#define FILE  char  /* supports "FILE *fp[x];" declarations */
#define YES      1  /* true */
#define NO       0  /* false */
#define TRUE     1
#define FALSE    0
#define NULL     0  /* zero */
#define CR      13  /* ASCII carriage return */
#define LF      10  /* ASCII line feed */
#define BELL     7  /* ASCII bell */
#define SPACE  ' '  /* ASCII space */
#define NEWLINE LF  /* Small C newline character */

/* Macros
  Functions marked with a star (*) are implemented, please add the other
  functions, if you know how.

	Macro Name	Description
----------------------------------------------------------------------------
	clrscrn		Clears The Text from the Screen
*	clrlcd		Clears the hole LCD screen
*	indicatoroff	This turns the annoying run indicator off
*	indicatoron	This turns the annoying run indicator on
	displaygraph	This function displays whatever graphing equations 
			are stored in the calculator.
	nl		This function makes a new line on the screen like 
			a \n in Most C programing

	screencopy	This command copies the ti backbuffer to the screen
	clearbuffer	This command clears the ti backbuffer
*/

#define indicatoron	asm("\tcall BUSY_ON\n")
#define indicatoroff	asm("\tcall BUSY_OFF\n")
#define clrlcd		asm("\tcall CLEARLCD\n")



/* Not standard things, Switched off...
#define normtext	asm("\tres 3,(IY+05)\n")
#define invtext		asm("\tset 3,(IY+05)\n")
  Scroll the screen
#define scroll   asm("\tcall SCROLL_UP\n")
  Call this before you call scroll the first time
#define scroll_i asm("\tres 1,(IY+0D)\n")
****Predefined memory positions****
  The current text cursor positions
extern char _text_x (0x800c);
extern char _text_y (0x800d);
  The current menu text cursor positions
extern char _menu_x (0x8333);
extern char _menu_y (0x8334);
  The top and bottom of the screen, as used by scroll (normally 0 and 8) */
extern char _scr_top (0x8B2F);
extern char _scr_btm (0x8B30);
*/

/* Pixel Definitions

These are used when calling functions like line, pixel, and Box

PT_OFF		Turns the pixel/pixels off
PT_ON		Turns the pixel/pixels on
PT_CHG		Inverts the pixel/pixels

*/

#define PT_OFF		0x00
#define PT_ON		0x01
#define PT_CHG		0x02

/* Basic TI Commands
  Functions marked with a star (*) are implemented, please add the other
  functions, if you know how.
  Functions marked with an '?' sould be revised, if needed

	Function	Description
--------------------------------------------------------------------------
*	setxy(x,y)	This function moves the text cursor to the specified
			(x,y) location

	putm(c)		Puts a character on the current location

	putc(c)		Puts the character on the current location and move the
			cursor over one space

*?	puts(str)	This command puts a specified string at the current
			cursor location and moves the cursor location up

*	getkey()	This command waits for a key or the APD register
			to clear. The calculator will be in low power stand-
			by during this process. It returns a value refer
			to the k* table.
*/

setxy(x,y) char x, y; {
#asm
	ld	hl,2
	add	hl,sp
	ld	b,(hl)
	inc	hl
	inc	hl	;???again??? (Henk Poley)
	ld	c,(hl)
	ld	($800C),bc
#endasm
}

puts(str) char* str; {
#asm
	ld	hl,2
	add	hl,sp
	call	LD_HL_MHL
	call	D_ZT_STR
#endasm
}

getkey() {
#asm
_gkloop:
	halt		; to reduce power consumption
	call	GET_KEY
	cp	0
	jr	z,_gkloop
	ld	l,a
	xor	a
	ld	h,a
#endasm
}

/* Not so standard routines, switched off
**** Function definitions of them ****
   putn(int)	prints an integer to the screen
		  (there is no menutext version)
   putc(char)	prints a character in normal text
   putc_m(char)	prints a character in menu text
   puts(char*)	prints a string in normal text
   puts_m(char*)prints a string in menu text
   setxy_m(x,y)	sets the menu text cursor position
   getkey()	waits for a key, and returns its value
		  (see bottom for values)
   _exit()	exits the application immediately,
		  returning to Usgard
   graphpage()	must be called before any calls to 
		  graphics routines
   rand()	returns a random 8-bit number

putn(n) int n; {
#asm
   ld hl,2
   add hl,sp
   call LD_HL_MHL
   call D_HL_DECI
#endasm
}

putc(c) char c; {
#asm
   ld hl,2
   add hl,sp
   ld a,(hl)
   call TX_CHARPUT
#endasm
}

putc_m(c) char c; {
#asm
   ld hl,2
   add hl,sp
   ld a,(hl)
   call M_CHARPUT
#endasm
}

setxy_m(x,y) char x, y; {
#asm
   ld hl,2
   add hl,sp
   ld b,(hl)
   inc hl
   inc hl
   ld c,(hl)
   ld ($8333),bc
#endasm
}

puts_m(str) char* str; {
#asm
   ld hl,2
   add hl,sp
   call LD_HL_MHL
   call D_ZM_STR
#endasm
}

_exit () {
#asm
  jp &_cleanup
#endasm
}

graphpage() {
#asm
   ld a,4
   out (5),a
#endasm
}

rand() {
#asm
   call RANDOM
   ld  l,a
   xor a
   ld  h,a
#endasm
}
*/


/* These are the values that would be returned by getkey() */
/* Not all (!) of the valuenames are renamed to their propper
   name. If anyone feels free to do so, THANKS!!! */
/* Need to be sorted! */


/* Do you need this one? The getkey() routine does 'cp 0'*/
#define K_NOKEY       0x00
#define kDown		0x01
#define kLeft		0x02
#define kRight		0x03
#define kUp		0x04
#define kEnter		0x09
#define kAdd		0x0A
#define kSub		0x0B
#define kMul		0x0C
#define kDiv		0x0D
/* what to raise??? */
#define K_RAISE       0x0E
#define kClear		0x0F
/* this seems to be the (small) minus sign */
#define K_SIGN        0x11
#define k3		0x12
#define k6		0x13
#define k9		0x14
/* RIGHTPAR ??? */
#define K_RIGHTPAR    0x15
#define kTan		0x16
/* Does anybody know a good one to define here??? */
#define K_CUSTOM      0x17
/* Is DOT the same as 'decimal point'??? */
#define kDecPnt		0x19
#define k2		0x1A
#define k5		0x1B
#define k8		0x1C
/* LEFTPAR ??? */
#define K_LEFTPAR     0x1D
#define kCos		0x1E
#define kPrgm		0x1F
#define kDEL		0x20
#define k0		0x21
#define k1		0x22
#define k4		0x23
#define k7		0x24
#define kEE		0x25
#define kSin		0x26
#define kSTAT		0x27
#define K_XVAR        0x28
/* This one ('K_ON') is normaly not returned by getkey()
on the TI83(+), but the TI86 does, there it is named 'kOn' */
#define kOn		0x29
#define kStore		0x2A	/* Also the '=' */
#define kCOMMA		0x2B
#define kSQUARE		0x2C
#define kLN		0x2D
#define kLOG		0x2E
#define kGRAPH		0x2F
/* This one ('K_ALPHA') is normaly not
returned by getkey() on the TI83(+)/TI86 */
#define K_ALPHA       0x30
/* what shall we do with these? Maybe add 
them to the other calcs include-files? And
use there the values of 'Y=', 'Window',
'Zoom', 'Trace', and 'Graph'? */
#define K_F5          0x31
#define K_F4          0x32
#define K_F3          0x33
#define K_F2          0x34
#define K_F1          0x35
/* This one ('K_SECOND') is normaly not returned
by getkey() on the TI83(+)/TI86 */
#define K_SECOND      0x36
#define kQuit		0x37
#define kExit		0x37
/* This key is not known on the TI83(+)/TI86 */
#define K_MORE        0x38

#define kCapX		0x0A
#define kCapT		0x0B
#define kCapT		0x0C
#define kCapJ		0x0D
#define kCapE		0x0E
#define kSPACE		0x11
#define kCapW		0x12
#define kCapS		0x13
#define kCapN		0x14
#define kCapI		0x15
#define kCapD		0x16
#define kCapZ		0x19
#define kCapV		0x1A
#define kCapR		0x1B
#define kCapM		0x1C
#define kCapH		0x1D
#define kCapC		0x1E
#define kCapY		0x21
#define kCapU		0x22
#define kCapQ		0x23
#define kCapL		0x24
#define kCapG		0x25
#define kCapB		0x26
#define kCapP		0x2B
#define kCapK		0x2C
#define kCapF		0x2D
#define kCapA		0x2E


#endif /* __TILOADED__ */
