#ifndef USGLIB_H
#define USGLIB_H

/* These ROM_CALLs are implemented as defines to remove the overhead of
   function call. Since these are not functions, they are called like this:

   clrscr;  [ not clrscr(); ] */

/* Set text mode */
#define normtext asm("\tres 3,(IY+05)\n")
#define invtext  asm("\tset 3,(IY+05)\n")
/* Turn the busy indicator on and off */
#define busyon   asm("\tcall BUSY_ON\n")
#define busyoff  asm("\tcall BUSY_OFF\n")
/* Scroll the screen */
#define scroll   asm("\tcall SCROLL_UP\n")
/* Call this before you call scroll the first time */
#define scroll_i asm("\tres 1,(IY+0D)\n");
/* Clear the display */
#define clrscr   asm("\tcall CLEARLCD\n")

/* Predefined memory positions */
/* The current text cursor positions */
extern char _text_x (0x800c);
extern char _text_y (0x800d);
/* The current menu text cursor positions */
extern char _menu_x (0x8333);
extern char _menu_y (0x8334);
/* The top and bottom of the screen, as used by scroll (normally 0 and 8) */
extern char _scr_top (0x8B2F);
extern char _scr_btm (0x8B30);

/* Function definitions
   putn(int) - prints an integer to the screen (there is no menutext version
   putc(char) - prints a character in normal text
   putc_m(char) - prints a character in menu text
   puts(char*) - prints a string in normal text
   puts_m(char*) - prints a string in menu text
   setxy(x,y) - sets the text cursor position
   setxy_m(x,y) - sets the menu text cursor position
   getkey() - waits for a key, and returns its value (see bottom for values)
   _exit() - exits the application immediately, returning to Usgard
   graphpage() - must be called before any calls to graphics routines
   rand() - returns a random 8-bit number

*/
putn(n) int n; {
#asm
   ld hl,2
   add hl,sp
   call LD_HL_MHL
   call D_HL_DECI
#endasm
}

putc(c) char c; {
#asm
   ld hl,2
   add hl,sp
   ld a,(hl)
   call TX_CHARPUT
#endasm
}

putc_m(c) char c; {
#asm
   ld hl,2
   add hl,sp
   ld a,(hl)
   call M_CHARPUT
#endasm
}

setxy(x,y) char x, y; {
#asm
   ld hl,2
   add hl,sp
   ld b,(hl)
   inc hl
   inc hl
   ld c,(hl)
   ld ($800c),bc
#endasm
}

puts(str) char* str; {
#asm
   ld hl,2
   add hl,sp
   call LD_HL_MHL
   call D_ZT_STR
#endasm
}

setxy_m(x,y) char x, y; {
#asm
   ld hl,2
   add hl,sp
   ld b,(hl)
   inc hl
   inc hl
   ld c,(hl)
   ld ($8333),bc
#endasm
}

puts_m(str) char* str; {
#asm
   ld hl,2
   add hl,sp
   call LD_HL_MHL
   call D_ZM_STR
#endasm
}

getkey() {
#asm
_gkloop:
   halt ; to reduce power consumption
   call GET_KEY
   cp 0
   jr z,_gkloop
   ld l,a
   xor a
   ld h,a
#endasm
}

_exit () {
#asm
  jp &_cleanup
#endasm
}

graphpage() {
#asm
   ld a,4
   out (5),a
#endasm
}

rand() {
#asm
   call RANDOM
   ld  l,a
   xor a
   ld  h,a
#endasm
}


/* Definitions for TI-85 keys */

#define K_NOKEY       0x00
#define K_DOWN        0x01
#define K_LEFT        0x02
#define K_RIGHT       0x03
#define K_UP          0x04
#define K_ENTER       0x09
#define K_PLUS        0x0A
#define K_MINUS       0x0B
#define K_STAR        0x0C
#define K_SLASH       0x0D
#define K_RAISE       0x0E
#define K_CLEAR       0x0F
#define K_SIGN        0x11

#define K_3           0x12
#define K_6           0x13
#define K_9           0x14
#define K_RIGHTPAR    0x15
#define K_TAN         0x16
#define K_CUSTOM      0x17
#define K_DOT         0x19
#define K_2           0x1A
#define K_5           0x1B
#define K_8           0x1C
#define K_LEFTPAR     0x1D

#define K_COS         0x1E
#define K_PRGM        0x1F
#define K_DEL         0x20
#define K_0           0x21
#define K_1           0x22
#define K_4           0x23
#define K_7           0x24
#define K_EE          0x25
#define K_SIN         0x26
#define K_STAT        0x27
#define K_XVAR        0x28

#define K_ON          0x29
#define K_STO         0x2A
#define K_COMMA       0x2B
#define K_SQUARE      0x2C
#define K_LN          0x2D
#define K_LOG         0x2E
#define K_GRAPH       0x2F
#define K_ALPHA       0x30
#define K_F5          0x31
#define K_F4          0x32
#define K_F3          0x33
#define K_F2          0x34
#define K_F1          0x35
#define K_SECOND      0x36

#define K_EXIT        0x37
#define K_MORE        0x38

#endif
